@@ -8,7 +8,6 @@ use itertools::Itertools;
 use num_traits::Signed;
 use std::collections::BTreeSet;
 use std::iter::FusedIterator;
-use std::mem::MaybeUninit;
 use std::ops::{Deref, DerefMut, Index, IndexMut, Neg, Range};
 use std::slice::{Iter, IterMut};
 use thiserror::Error;
@@ -232,20 +231,6 @@ impl<C> Matrix<C> {
         })
     }
 
-    /// Construct a new Matrix with uninitialized content.
-    pub fn new_uninit(rows: usize, columns: usize) -> Matrix<MaybeUninit<C>> {
-        let data_len = rows * columns;
-        let mut data = Vec::with_capacity(data_len);
-        unsafe {
-            data.set_len(data_len);
-        }
-        Matrix {
-            rows,
-            columns,
-            data,
-        }
-    }
-
     /// Create new square matrix from vector values. The first value
     /// will be assigned to index (0, 0), the second one to index (0, 1),
     /// and so on. An error is returned if the number of values is not a
@@ -636,23 +621,6 @@ impl<C> Matrix<C> {
     }
 }
 
-impl<C> Matrix<MaybeUninit<C>> {
-    /// Convert to `Matrix<C>`.
-    ///
-    /// # Safety
-    ///
-    /// As with [`MaybeUninit::assume_init()`], it is up to the caller to guarantee
-    /// that the value really is in an initialized state. Calling this when the content
-    /// is not yet fully initialized causes immediate undefined behavior.
-    pub unsafe fn assume_init(self) -> Matrix<C> {
-        Matrix {
-            rows: self.rows,
-            columns: self.columns,
-            data: std::mem::transmute(self.data),
-        }
-    }
-}
-
 impl<C> Index<(usize, usize)> for Matrix<C> {
     type Output = C;
 
