@@ -574,23 +574,6 @@ fn in_direction() {
     );
 }
 
-#[test]
-fn uninit() {
-    struct NonClonable(usize);
-    let mut mat = Matrix::<NonClonable>::new_uninit(3, 3);
-    for row in 0..mat.rows {
-        for column in 0..mat.columns {
-            mat[(row, column)].write(NonClonable(3 * row + column));
-        }
-    }
-    let mat = unsafe { mat.assume_init() };
-    for row in 0..mat.rows {
-        for column in 0..mat.columns {
-            assert_eq!(mat[(row, column)].0, row * 3 + column);
-        }
-    }
-}
-
 #[test]
 fn map() {
     let m = Matrix::new(3, 3, 10);
